# OwnTools
2021-12-27 Created
2024-05-06 Upload to PyPi

##
1. change version
2. python setup.py sdist bdist_wheel
2. python setup.py develop 
4. twine upload dist/*

### 2024-5-19

    1.trans_to_date
    2.trans_to_datetime
